GarnishListTileStyle class

Style configuration for GarnishListTile.

Constructors

GarnishListTileStyle({Color? backgroundColor, Color? selectedColor, Color? hoverColor, EdgeInsets? padding, BorderRadius? borderRadius, TextStyle? titleStyle, TextStyle? subtitleStyle, double? contentSpacing})
Creates a list tile style.
const

Properties

backgroundColor Color?
Default background color.
final
borderRadius BorderRadius?
Border radius.
final
contentSpacing double?
Spacing between elements.
final
hashCode int
The hash code for this object.
no setterinherited
hoverColor Color?
Background color when hovered.
final
padding EdgeInsets?
Padding around the content.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color?
Background color when selected.
final
subtitleStyle TextStyle?
Subtitle text style.
final
titleStyle TextStyle?
Title text style.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited