GarnishNavBarVariant enum

The visual variant of a GarnishNavBar.

Inheritance
Available extensions

Values

solid → const GarnishNavBarVariant

A solid nav bar with background color.

transparent → const GarnishNavBarVariant

A transparent nav bar.

bordered → const GarnishNavBarVariant

A nav bar with a bottom border.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GarnishNavBarVariant>
A constant List of the values in this enum, in order of their declaration.