GarnishTimePickerStyle class

Style configuration for GarnishTimePicker.

Constructors

GarnishTimePickerStyle({Color? backgroundColor, Color? selectedColor, Color? textColor, Color? disabledColor, Color? borderColor, BorderRadius? borderRadius, double? columnWidth, double? itemHeight})
Creates a time picker style.
const

Properties

backgroundColor Color?
Background color of the picker.
final
borderColor Color?
Border color of the picker.
final
borderRadius BorderRadius?
Border radius of the picker.
final
columnWidth double?
Width of each column (hour, minute, period).
final
disabledColor Color?
Color for disabled time values.
final
hashCode int
The hash code for this object.
no setterinherited
itemHeight double?
Height of each item in the picker.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color?
Color for the selected time value.
final
textColor Color?
Text color for time values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited