KElevation class abstract final

Elevation/shadow level constants.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

lg → const int
Large elevation
md → const int
Medium elevation
none → const int
No elevation
sm → const int
Small elevation
xl → const int
Extra large elevation
xs → const int
Extra small elevation (subtle)