KSpacing class abstract final

Compile-time spacing constants (in logical pixels).

For theme-based spacing, use GarnishTheme.of(context).spacing.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

lg → const double
16px
md → const double
12px
none → const double
0px
sm → const double
8px
xl → const double
24px
xs → const double
4px
xxl → const double
32px
xxs → const double
2px
xxxl → const double
48px