GarnishAnimationController class
Controller for advanced animation control (play, reverse, reset).
For most use cases, just use animation.trigger() instead.
Use this controller only when you need:
- Reversing the animation
- Resetting to initial state
Example:
final controller = GarnishAnimationController();
GarnishButton(
child: Text('Animated'),
animation: GarnishAnimation.shake(),
animationController: controller,
)
controller.play(); // Play from start
controller.reverse(); // Play backwards
controller.reset(); // Reset to initial state
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAttached → bool
-
Whether this controller is attached to a widget.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
play(
) → void - Play the animation from the beginning.
-
reset(
) → void - Reset the animation to its initial state.
-
reverse(
) → void - Reverse the animation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited