GarnishAnimationType enum
Types of preset animations available in Garnish UI.
Values
- none → const GarnishAnimationType
-
No animation.
- fadeIn → const GarnishAnimationType
-
Fade in from transparent to opaque.
- fadeSlideUp → const GarnishAnimationType
-
Fade in while sliding up from below.
- fadeSlideDown → const GarnishAnimationType
-
Fade in while sliding down from above.
- fadeSlideLeft → const GarnishAnimationType
-
Fade in while sliding in from the left.
- fadeSlideRight → const GarnishAnimationType
-
Fade in while sliding in from the right.
- scale → const GarnishAnimationType
-
Scale up from a smaller size.
- bounce → const GarnishAnimationType
-
Bounce effect animation.
- pulse → const GarnishAnimationType
-
Pulse effect that scales up and down.
- shake → const GarnishAnimationType
-
Horizontal shake effect.
- flip → const GarnishAnimationType
-
3D flip animation.
- custom → const GarnishAnimationType
-
Custom animation with user-defined transforms.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GarnishAnimationType> - A constant List of the values in this enum, in order of their declaration.