GarnishBottomSheetContainer class
Container for showing Garnish bottom sheets.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
close(
BuildContext context, [dynamic result]) → void - Closes the currently open bottom sheet.
-
show<
T> ({required BuildContext context, required WidgetBuilder builder, bool isDismissible = true, bool enableDrag = true, Color? barrierColor}) → Future< T?> - Shows a bottom sheet.