GarnishStyledGraph class
A graph (line/bar) that adapts its appearance based on the style category.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GarnishStyledGraph
- Available extensions
Constructors
-
GarnishStyledGraph({Key? key, required List<
GarnishGraphPoint> data, GarnishGraphVariant variant = GarnishGraphVariant.line, GarnishStyleCategory? styleCategory, bool showGrid = true, bool showLabels = true, double? width, double height = 160}) -
Creates a styled graph.
const
Properties
-
data
→ List<
GarnishGraphPoint> -
Data points to plot.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Height of the chart.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showGrid → bool
-
Whether to draw grid lines.
final
- showLabels → bool
-
Whether to show labels.
final
- styleCategory → GarnishStyleCategory?
-
The visual style category to apply.
final
- variant → GarnishGraphVariant
-
Line or bar variant.
final
- width → double?
-
Width of the chart (expands if null).
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withAnimation(
GarnishAnimation animation, {ValueKey? animationKey, VoidCallback? onComplete, GarnishAnimationController? controller}) → Widget -
Available on Widget, provided by the GarnishAnimationExtension extension
Wraps this widget with a GarnishAnimated.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited